@@ -30,12 +30,12 @@ from flask import Flask
 from .checkerservice import CHECKER_METHODS, init_service
 from .logging import ELKFormatter
 from .nosqldict import NoSqlDict
-from .results import EnoException, Result
+from .results import CheckerResult, EnoException, Result
 from .storeddict import DB_DEFAULT_DIR, DB_GLOBAL_CACHE_SETTING, StoredDict
 from .useragents import random_useragent
 from .utils import SimpleSocket, snake_caseify
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     # The import might fail in UWSGI, see the comments below.
     import requests
 
@@ -399,13 +399,13 @@ class BaseChecker(metaclass=_CheckerMeta):
 
     # ---- Basic checker functionality ---- #
 
-    def run(self, method: Optional[Union[str, Callable]] = None) -> Result:
+    def run(self, method: Optional[Union[str, Callable]] = None) -> CheckerResult:
         """
         Execute the checker and catch errors along the way.
 
         :param method: When calling run, you may call a different method than the one passed on Checker creation
                         using this optional param.
-        :return: the Result code as int, as per the Result enum.
+        :return: A CheckerResult as a representation of the CheckerResult response as definded in the Spec.
         """
         try:
             if callable(method):
@@ -454,8 +454,9 @@ class BaseChecker(metaclass=_CheckerMeta):
 
                 if ignore_run:
                     self.debug("run ignored -- preemptively returned OK")
-                    return Result.OK
+                    return CheckerResult(Result.OK)
 
+                # call the function with the name method ""
                 ret = getattr(self, snake_caseify(method))()
             if Result.is_valid(ret):
                 ret = Result(
@@ -465,10 +466,10 @@ class BaseChecker(metaclass=_CheckerMeta):
                 self.team_db[
                     f"__Checker-internals-RESULT:{str(method)},{self.flag_round},{self.flag_idx}__"
                 ] = ret.name
-                return ret
+                return CheckerResult(ret)
             if ret is not None:
                 self.error("Illegal return value from {}: {}".format(self.method, ret))
-                return (
+                return CheckerResult(
                     Result.INTERNAL_ERROR
                 )  # , "Illegal return value from {}: {}".format(self.method, ret)
 
@@ -477,7 +478,7 @@ class BaseChecker(metaclass=_CheckerMeta):
             self.team_db[
                 f"__Checker-internals-RESULT:{str(method)},{self.flag_round},{self.flag_idx}__"
             ] = "OK"
-            return Result.OK
+            return CheckerResult(Result.OK, None)
 
         except EnoException as eno:
             stacktrace = "".join(
@@ -489,10 +490,10 @@ class BaseChecker(metaclass=_CheckerMeta):
                 ),
                 exc_info=eno,
             )
-            return Result(eno.result)  # , eno.message
+            return CheckerResult.from_exception(eno)  # , eno.message
         except self.requests.HTTPError as ex:
             self.info("Service returned HTTP Errorcode [{}].".format(ex), exc_info=ex)
-            return Result.MUMBLE  # , "HTTP Error" #For now
+            return CheckerResult(Result.MUMBLE, "Service returned HTTP Error",)
         except (
             self.requests.ConnectionError,  # requests
             self.requests.exceptions.ConnectTimeout,  # requests
@@ -505,13 +506,15 @@ class BaseChecker(metaclass=_CheckerMeta):
             self.info(
                 "Error in connection to service occurred: {}\n".format(ex), exc_info=ex
             )
-            return Result.OFFLINE  # , ex.message
+            return CheckerResult(
+                Result.OFFLINE, message="Error in connection to service occured"
+            )  # , ex.message
         except Exception as ex:
             stacktrace = "".join(traceback.format_exception(None, ex, ex.__traceback__))
             self.error(
                 "Unhandled checker error occurred: {}\n".format(stacktrace), exc_info=ex
             )
-            return Result.INTERNAL_ERROR  # , ex.message
+            return CheckerResult.from_exception(ex)  # , ex.message
         finally:
             for db in self._active_dbs.values():
                 # A bit of cleanup :)
@@ -627,8 +630,7 @@ class BaseChecker(metaclass=_CheckerMeta):
         """
         try:
             db = self._active_dbs[name]
-            # TODO: make the NoSQLDict use the checker's logger
-            db.logger = self.logger  # type: ignore
+            db.logger = self.logger
             # TODO: Settng a new Logger backend may throw logs in the wrong direction in a multithreaded environment!
             return db
         except KeyError:
@@ -655,6 +657,7 @@ class BaseChecker(metaclass=_CheckerMeta):
                     port=port,
                     username=username,
                     password=password,
+                    logger=self.logger,
                 )
             else:
                 self.debug(
@@ -783,7 +786,7 @@ class BaseChecker(metaclass=_CheckerMeta):
         """
         self.http_session.headers["User-Agent"] = useragent
 
-    def http_useragent_randomize(self):
+    def http_useragent_randomize(self) -> str:
         """
         Choose a new random http useragent.
 
@@ -804,7 +807,7 @@ class BaseChecker(metaclass=_CheckerMeta):
         scheme: str = "http",
         raise_http_errors: bool = False,
         timeout: Optional[int] = None,
-        **kwargs,
+        **kwargs: Any,
     ) -> "requests.Response":
         """
         Perform a (http) requests.post to the current host.
@@ -832,7 +835,7 @@ class BaseChecker(metaclass=_CheckerMeta):
         scheme: str = "http",
         raise_http_errors: bool = False,
         timeout: Optional[int] = None,
-        **kwargs,
+        **kwargs: Any,
     ) -> "requests.Response":
         """
         Perform a (http) requests.get to the current host.
@@ -861,7 +864,7 @@ class BaseChecker(metaclass=_CheckerMeta):
         scheme: str = "http",
         raise_http_errors: bool = False,
         timeout: Optional[int] = None,
-        **kwargs,
+        **kwargs: Any,
     ) -> "requests.Response":
         """
         Perform an http request (requests lib) to the current host.
@@ -896,7 +899,7 @@ class BaseChecker(metaclass=_CheckerMeta):
 
 def run(
     checker_cls: Type[BaseChecker], args: Optional[Sequence[str]] = None,
-) -> Optional[Result]:
+) -> Optional[CheckerResult]:
     """
     Run a checker, either from cmdline or as uwsgi script.
 
@@ -913,5 +916,5 @@ def run(
         checker_args = vars(parsed)
         del checker_args["runmode"]  # will always be 'run' at this point
         result = checker_cls(**vars(parsed)).run()
-        print("Checker run resulted in Result.{}".format(result.name))
+        print(f"Checker run resulted in Result. {result.result.name}")
         return result
