@@ -25,7 +25,7 @@ from typing import (
 
 from .results import BrokenServiceException, OfflineException
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     import requests
 
 PORT_MAX = 65535
@@ -37,7 +37,7 @@ utilslogger.setLevel(logging.DEBUG)
 
 def assert_in(o1: Any, o2: Any, message: Optional[str] = None) -> None:
     """
-    Raise an exception if o1 not in o2.
+    Raise a BrokenServiceException if o1 not in o2.
 
     :param o1: the object that should be in o2
     :param o2: the object to look in
@@ -53,7 +53,7 @@ def assert_equals(
     o1: Any, o2: Any, message: Optional[str] = None, autobyteify: bool = False
 ) -> None:
     """
-    Raise an exception if o1 != o2.
+    Raise a BrokenServiceException if o1 != o2.
 
     :param o1: the first object
     :param o2: the second object
@@ -94,7 +94,7 @@ def ensure_unicode(obj: Union[bytes, str, Any]) -> str:
     :param obj: str or bytes (or anything else) to convert to string representation
     :return: the string representation of the object
     """
-    if str is None:
+    if obj is None:
         raise ValueError("Cannot stringify None")
     if isinstance(obj, bytes):
         return obj.decode("utf-8")
@@ -111,11 +111,12 @@ def ensure_valid_filename(s: str, min_length: int = 3) -> str:
     :param min_length: if the result is smaller than this, the method will fall back to base64.
     :return: all illegal chars stripped or base64ified if it gets too small
     """
-    orig = s
     s = str(s).strip().replace(" ", "_")
     s = re.sub(r"(?u)[^-\w.]", "", s)
-    if len(s) < min_length:
-        s = base64ify(orig, "+-")
+    if not s:
+        s = "_"
+    while len(s) < min_length:
+        s = base64ify(s, "+-")
     return s
 
 
@@ -153,7 +154,7 @@ def base64ify(s: Union[str, bytes], altchars: Union[str, bytes] = None) -> str:
     :return: base64 representation
     """
     s = ensure_bytes(s)
-    if altchars != None:
+    if altchars:
         altchars = ensure_bytes(altchars)
         return base64.b64encode(s, altchars).decode("utf-8")
     else:
@@ -171,7 +172,7 @@ def debase64ify(
     :return: the decoded value
     """
     s = ensure_bytes(s)
-    if altchars != None:
+    if altchars:
         altchars = ensure_bytes(altchars)
         return base64.b64decode(s, altchars).decode("utf-8")
     else:
@@ -254,38 +255,38 @@ def serve_once(
     # see https://github.com/psf/requests/issues/2925
     import requests
 
-    if logger is None:
-        logger = utilslogger
-    if headers is None:
-        headers = {}
+    logger_: logging.Logger = logger or utilslogger
+    headers_: Dict[str, str] = headers or {}
     if isinstance(html, requests.Response):
-        html = html.text
-    if isinstance(html, str):
-        html = html.encode("UTF-8")
+        payload: bytes = html.text.encode("UTF-8")
+    elif isinstance(html, str):
+        payload = html.encode("UTF-8")
+    else:
+        payload = html
 
     class OutputHandler(BaseHTTPRequestHandler):
 
         # noinspection PyPep8Naming
-        def do_GET(self):
+        def do_GET(self) -> None:
             self.send_response(200)
             self.send_header("Content-type", content_type)
-            for key, value in headers.items():
+            for key, value in headers_.items():
                 self.send_header(key, value)
             self.end_headers()
-            self.wfile.write(html)
-            logger.info("Served HTTP once. Stopping.")
+            self.wfile.write(payload)
+            logger_.info("Served HTTP once. Stopping.")
             start_daemon(self.server.shutdown)
 
     for port in range(start_port, PORT_MAX):
         try:
             server = HTTPServer(("", port), OutputHandler)
-            logging.debug("Serving {} bytes on port {}".format(len(html), port))
+            logging.debug("Serving {} bytes on port {}".format(len(payload), port))
             start_daemon(server.serve_forever)
             time.sleep(0.1)  # some extra time thrown in for good measure. :)
             return port
         except OSError as ex:
             if not autoincrement_port:
-                logger.info(
+                logger_.info(
                     "Serve once was not set to automatically increment port {} but faced socket exception{}".format(
                         start_port, ex
                     ),
@@ -368,7 +369,7 @@ class SimpleSocket(telnetlib.Telnet):
 
     def expect(
         self,
-        regexes: Sequence[Union[Pattern[bytes], bytes]],
+        regexes: Sequence[Union[Pattern[bytes], bytes, str]],
         timeout: Optional[int] = None,
     ) -> Tuple[int, Optional[Match[bytes]], bytes]:
         """
@@ -387,9 +388,11 @@ class SimpleSocket(telnetlib.Telnet):
             timeout = self.current_default_timeout
 
         # Make sure all strings are bytes, ignore compiled Regexes.
-        regexes = [ensure_bytes(x) if isinstance(x, str) else x for x in regexes]
+        regexes_: List[Union[Pattern[bytes], bytes]] = [
+            ensure_bytes(x) if isinstance(x, str) else x for x in regexes
+        ]
 
-        return super().expect(list=regexes, timeout=timeout)
+        return super().expect(list=regexes_, timeout=timeout)
 
     def read_until(
         self, match: Union[bytes, str], timeout: Optional[int] = None
